package App::BenchStartupPauseClis;

our $DATE = '2015-08-24'; # DATE
our $VERSION = '0.01'; # VERSION

1;
# ABSTRACT: Benchmark startup time of pause CLI's

__END__

=pod

=encoding UTF-8

=head1 NAME

App::BenchStartupPauseClis - Benchmark startup time of pause CLI's

=head1 VERSION

This document describes version 0.01 of App::BenchStartupPauseClis (from Perl distribution App-BenchStartupPauseClis), released on 2015-08-24.

=head1 SYNOPSIS

See the included scripts:

=over

=item * L<bench-startup-pause-clis>

=back

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/App-BenchStartupPauseClis>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-App-BenchStartupPauseClis>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=App-BenchStartupPauseClis>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2015 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
